/*----------------------------------------------------------------------------*/
/*
  This file is generated by code_saturne, a general-purpose CFD tool.
*/
/*----------------------------------------------------------------------------*/

#include "cs_defs.h"

/*----------------------------------------------------------------------------
 * Standard C library headers
 *----------------------------------------------------------------------------*/

#include <assert.h>
#include <math.h>

#if defined(HAVE_MPI)
#include <mpi.h>
#endif

/*----------------------------------------------------------------------------
 *  Local headers
 *----------------------------------------------------------------------------*/

#include "cs_headers.h"

/*----------------------------------------------------------------------------*/

BEGIN_C_DECLS

/*----------------------------------------------------------------------------*/

cs_real_t *
cs_meg_boundary_function(const char       *zone_name,
                         const cs_lnum_t   n_elts,
                         const cs_lnum_t  *elt_ids,
                         const cs_real_t   xyz[][3],
                         const char       *field_name,
                         const char       *condition)
{
  cs_real_t *new_vals = NULL;

  /* User defined formula for "direction" over BC=inlet
    --------------------------------------------------- */

  if (strcmp(field_name, "direction") == 0 &&
      strcmp(condition, "formula") == 0 &&
      strcmp(zone_name, "inlet") == 0) {

    const cs_lnum_t vals_size = n_elts * 3;
    BFT_MALLOC(new_vals, vals_size, cs_real_t);

    const cs_real_t inlet_width = cs_notebook_parameter_value_by_name("inlet_width");

    cs_real_t ang = -1.;
    for (cs_lnum_t e_id = 0; e_id < n_elts; e_id++) {
      cs_lnum_t b_e_id = elt_ids[e_id];
      const cs_real_t y = xyz[b_e_id][1];

      ang = atan(y * 0.445333 / (inlet_width * 100.0 / 2.0));
      new_vals[0 * n_elts + e_id] = cos(ang);
      new_vals[1 * n_elts + e_id] = sin(ang);
      new_vals[2 * n_elts + e_id] = 0;
    }
  }

  /* User defined formula for "turbulence_kw" over BC=inlet
    ------------------------------------------------------- */

  if (strcmp(field_name, "turbulence_kw") == 0 &&
      strcmp(condition, "formula") == 0 &&
      strcmp(zone_name, "inlet") == 0) {

    const cs_lnum_t vals_size = n_elts * 2;
    BFT_MALLOC(new_vals, vals_size, cs_real_t);

    const cs_real_t turbIntensity = cs_notebook_parameter_value_by_name("turbIntensity");
    const cs_real_t vel_inlet = cs_notebook_parameter_value_by_name("vel_inlet");
    const cs_real_t almax = cs_glob_turb_ref_values->almax;

    cs_real_t I = -1.;
    for (cs_lnum_t e_id = 0; e_id < n_elts; e_id++) {
      cs_lnum_t b_e_id = elt_ids[e_id];
      I = turbIntensity;
      new_vals[0 * n_elts + e_id] = 1.5 * cs_math_pow2((I * vel_inlet));
      new_vals[1 * n_elts + e_id] = (pow(new_vals[0 * n_elts + e_id], 0.5)) / almax;
    }
  }
  return new_vals;
}

/*----------------------------------------------------------------------------*/

END_C_DECLS

